@@ -1,6 +1,6 @@
 package Bio::DB::Bam::AlignWrapper;
 
-# $Id: AlignWrapper.pm 23137 2010-05-05 17:56:28Z lstein $
+# $Id: AlignWrapper.pm 23217 2010-05-17 04:52:38Z lstein $
 
 =head1 NAME
 
@@ -165,6 +165,13 @@ sub seq_id {
     $self->{sam}->target_name($tid);
 }
 
+sub mate_seq_id {
+    my $self = shift;
+    my $tid  = $self->mtid;
+    return unless $tid >= 0;
+    $self->{sam}->target_name($tid);
+}
+
 sub abs_ref    { shift->seq_id }
 sub abs_start  { shift->start  }
 sub abs_end    { shift->end    }
@@ -379,6 +386,23 @@ sub format_attributes {
   return join ';',@result;
 }
 
+sub tam_line {
+    my $self = shift;
+    return join ("\t",
+		 $self->qname,
+		 $self->flag,
+		 $self->seq_id,
+		 $self->pos+1,
+		 $self->qual,
+		 $self->cigar_str,
+		 $self->mate_seq_id ? ($self->mate_seq_id eq $self->seq_id ? '=' : $self->mate_seq_id) : '*',
+		 $self->mpos || 0,
+		 $self->isize,
+		 $self->qseq,
+		 join('',map{chr($_+33)} $self->qscore),
+		 $self->aux
+	);
+}
 
 package Bio::DB::Bam::SplitAlignmentPart;
 
@@ -416,6 +440,4 @@ sub cigar_str {
     $d;
 }
 
-
-
 1;
